# UCX by Databricks Labs

<p align="center">
    <a href="https://github.com/databrickslabs/ucx">
        <img src="./docs/ucx/static/img/logo.svg" class="align-center" width="200" height="200" alt="logo" />
    </a>
</p>

<p align="center">
    <b>🚀 UCX - Unity Catalog Migration Assistant</b>
</p>

UCX is a toolkit for enabling Unity Catalog (UC) in your Databricks workspace. UCX provides commands and workflows for migrate tables and views to UC. UCX allows to rewrite dashboards, jobs and notebooks to use the migrated data assets in UC. And there are many more features


[![build](https://github.com/databrickslabs/ucx/actions/workflows/push.yml/badge.svg)](https://github.com/databrickslabs/ucx/actions/workflows/push.yml) [![codecov](https://codecov.io/github/databrickslabs/ucx/graph/badge.svg?token=p0WKAfW5HQ)](https://codecov.io/github/databrickslabs/ucx)  ![linesofcode](https://aschey.tech/tokei/github/databrickslabs/ucx?category=code)

# Documentation

Please refer to the [UCX documentation](https://databrickslabs.github.io/ucx/) for detailed information on how to use UCX.


# Developer documentation

Please refer to the [developer documentation](https://databrickslabs.github.io/ucx/docs/dev/) for information on how to contribute to UCX.

# Troubleshooting

For questions, troubleshooting or bug fixes, please see our [troubleshooting guide](https://databrickslabs.github.io/ucx/docs/reference/troubleshooting/). 

# Feedback

We welcome your feedback! Please submit an [an issue](https://github.com/databrickslabs/ucx/issues).


# Star History

[![Star History Chart](https://api.star-history.com/svg?repos=databrickslabs/ucx&type=Date)](https://star-history.com/#databrickslabs/ucx)


# Project Support
Please note that all projects in the databrickslabs GitHub account are provided for your exploration only, and are not formally supported by Databricks with Service Level Agreements (SLAs).  They are provided AS-IS, and we do not make any guarantees of any kind.  Please do not submit a support ticket relating to any issues arising from the use of these projects.

Any issues discovered through the use of this project should be filed as GitHub Issues on the Repo.  They will be reviewed as time permits, but there are no formal SLAs for support.